/********************************************************************************
** Form generated from reading UI file 'chatwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATWIDGET_H
#define UI_CHATWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ChatWidget
{
public:
    QGridLayout *gridLayout;
    KLineEdit *line;
    QPushButton *sendButton;
    QHBoxLayout *hLayout;
    QHBoxLayout *extraButtonsLayout;
    QSpacerItem *horizontalSpacer;
    QToolButton *toolButton;
    QHBoxLayout *consoleLayout;

    void setupUi(QWidget *ChatWidget)
    {
        if (ChatWidget->objectName().isEmpty())
            ChatWidget->setObjectName("ChatWidget");
        ChatWidget->resize(264, 258);
        gridLayout = new QGridLayout(ChatWidget);
        gridLayout->setObjectName("gridLayout");
        line = new KLineEdit(ChatWidget);
        line->setObjectName("line");

        gridLayout->addWidget(line, 6, 0, 1, 1);

        sendButton = new QPushButton(ChatWidget);
        sendButton->setObjectName("sendButton");

        gridLayout->addWidget(sendButton, 6, 1, 1, 1);

        hLayout = new QHBoxLayout();
        hLayout->setObjectName("hLayout");
        hLayout->setSizeConstraint(QLayout::SetMinimumSize);
        extraButtonsLayout = new QHBoxLayout();
        extraButtonsLayout->setObjectName("extraButtonsLayout");

        hLayout->addLayout(extraButtonsLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hLayout->addItem(horizontalSpacer);

        toolButton = new QToolButton(ChatWidget);
        toolButton->setObjectName("toolButton");

        hLayout->addWidget(toolButton);


        gridLayout->addLayout(hLayout, 4, 0, 1, 2);

        consoleLayout = new QHBoxLayout();
        consoleLayout->setObjectName("consoleLayout");
        consoleLayout->setSizeConstraint(QLayout::SetMaximumSize);

        gridLayout->addLayout(consoleLayout, 0, 0, 4, 2);


        retranslateUi(ChatWidget);
        QObject::connect(line, &KLineEdit::returnPressed, sendButton, qOverload<>(&QPushButton::click));

        sendButton->setDefault(true);


        QMetaObject::connectSlotsByName(ChatWidget);
    } // setupUi

    void retranslateUi(QWidget *ChatWidget)
    {
        sendButton->setText(tr2i18n("Send", nullptr));
        toolButton->setText(tr2i18n("...", nullptr));
        (void)ChatWidget;
    } // retranslateUi

};

namespace Ui {
    class ChatWidget: public Ui_ChatWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHATWIDGET_H

