/********************************************************************************
** Form generated from reading UI file 'knightsview_base.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KNIGHTSVIEW_BASE_H
#define UI_KNIGHTSVIEW_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KnightsView
{
public:
    QVBoxLayout *verticalLayout_2;
    QWidget *notificationWidget;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *showAllOffers;
    QGraphicsView *canvas;

    void setupUi(QWidget *KnightsView)
    {
        if (KnightsView->objectName().isEmpty())
            KnightsView->setObjectName("KnightsView");
        KnightsView->resize(489, 613);
        KnightsView->setAutoFillBackground(true);
        verticalLayout_2 = new QVBoxLayout(KnightsView);
        verticalLayout_2->setObjectName("verticalLayout_2");
        notificationWidget = new QWidget(KnightsView);
        notificationWidget->setObjectName("notificationWidget");
        gridLayout = new QGridLayout(notificationWidget);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(40, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 0, 1, 1);

        showAllOffers = new QPushButton(notificationWidget);
        showAllOffers->setObjectName("showAllOffers");

        gridLayout->addWidget(showAllOffers, 1, 1, 1, 1);


        verticalLayout_2->addWidget(notificationWidget);

        canvas = new QGraphicsView(KnightsView);
        canvas->setObjectName("canvas");
        canvas->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        canvas->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        verticalLayout_2->addWidget(canvas);


        retranslateUi(KnightsView);

        QMetaObject::connectSlotsByName(KnightsView);
    } // setupUi

    void retranslateUi(QWidget *KnightsView)
    {
        KnightsView->setWindowTitle(tr2i18n("Knights", nullptr));
        showAllOffers->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class KnightsView: public Ui_KnightsView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KNIGHTSVIEW_BASE_H

