/****************************************************************************
** Meta object code from reading C++ file 'board.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../knights-26.07.80/src/board.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'board.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Knights5BoardE_t {};
} // unnamed namespace

template <> constexpr inline auto Knights::Board::qt_create_metaobjectdata<qt_meta_tag_ZN7Knights5BoardE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Knights::Board",
        "pieceMoved",
        "",
        "Move",
        "activePlayerChanged",
        "Color",
        "displayedPlayerChanged",
        "centerChanged",
        "QPointF",
        "movePiece",
        "updateTheme",
        "updateGraphics",
        "changeDisplayedPlayer",
        "setCurrentColor",
        "setPlayerColors",
        "Colors",
        "MarkerType",
        "LegalMove",
        "Danger",
        "Motion"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pieceMoved'
        QtMocHelpers::SignalData<void(const Move &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'activePlayerChanged'
        QtMocHelpers::SignalData<void(Color)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'displayedPlayerChanged'
        QtMocHelpers::SignalData<void(Color)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'centerChanged'
        QtMocHelpers::SignalData<void(const QPointF &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'movePiece'
        QtMocHelpers::SlotData<void(const Move &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'updateTheme'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateGraphics'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeDisplayedPlayer'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentColor'
        QtMocHelpers::SlotData<void(Color)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'setPlayerColors'
        QtMocHelpers::SlotData<void(Colors)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MarkerType'
        QtMocHelpers::EnumData<enum MarkerType>(16, 16, QMC::EnumFlags{}).add({
            {   17, MarkerType::LegalMove },
            {   18, MarkerType::Danger },
            {   19, MarkerType::Motion },
        }),
    };
    return QtMocHelpers::metaObjectData<Board, qt_meta_tag_ZN7Knights5BoardE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Knights::Board::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsScene::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights5BoardE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights5BoardE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Knights5BoardE_t>.metaTypes,
    nullptr
} };

void Knights::Board::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Board *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pieceMoved((*reinterpret_cast<std::add_pointer_t<Move>>(_a[1]))); break;
        case 1: _t->activePlayerChanged((*reinterpret_cast<std::add_pointer_t<Color>>(_a[1]))); break;
        case 2: _t->displayedPlayerChanged((*reinterpret_cast<std::add_pointer_t<Color>>(_a[1]))); break;
        case 3: _t->centerChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 4: _t->movePiece((*reinterpret_cast<std::add_pointer_t<Move>>(_a[1]))); break;
        case 5: _t->updateTheme(); break;
        case 6: _t->updateGraphics(); break;
        case 7: _t->changeDisplayedPlayer(); break;
        case 8: _t->setCurrentColor((*reinterpret_cast<std::add_pointer_t<Color>>(_a[1]))); break;
        case 9: _t->setPlayerColors((*reinterpret_cast<std::add_pointer_t<Colors>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Board::*)(const Move & )>(_a, &Board::pieceMoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)(Color )>(_a, &Board::activePlayerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)(Color )>(_a, &Board::displayedPlayerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Board::*)(const QPointF & )>(_a, &Board::centerChanged, 3))
            return;
    }
}

const QMetaObject *Knights::Board::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Knights::Board::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights5BoardE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int Knights::Board::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Knights::Board::pieceMoved(const Move & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Knights::Board::activePlayerChanged(Color _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Knights::Board::displayedPlayerChanged(Color _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Knights::Board::centerChanged(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
