/********************************************************************************
** Form generated from reading UI file 'gamedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GAMEDIALOG_H
#define UI_GAMEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "khistorycombobox.h"

QT_BEGIN_NAMESPACE

class Ui_GameDialog
{
public:
    QGridLayout *gridLayout;
    QGroupBox *player1Box;
    QGridLayout *gridLayout_2;
    QRadioButton *rbPlayer1Human;
    QRadioButton *rbPlayer1Engine;
    KComboBox *cbPlayer1Engine;
    QPushButton *pbPlayer1Engine;
    QGroupBox *colorGroup;
    QVBoxLayout *verticalLayout;
    QRadioButton *colorWhite;
    QRadioButton *colorBlack;
    QRadioButton *colorRandom;
    QGroupBox *player2Box;
    QGridLayout *gridLayout_3;
    QRadioButton *rbPlayer2Human;
    QRadioButton *rbPlayer2Engine;
    KComboBox *cbPlayer2Engine;
    QToolButton *pbPlayer2Engine;
    QRadioButton *rbPlayer2Server;
    KHistoryComboBox *cbPlayer2Server;
    QGroupBox *gbTimeControl;
    QGridLayout *gridLayout_4;
    QCheckBox *cbTimeControl;
    QLabel *lNumberOfMoves;
    QSpinBox *sbNumberOfMoves;
    QLabel *timeLimitLabel;
    QSpinBox *sbTimeLimit;
    QLabel *timeIncrementLabel;
    QSpinBox *sbTimeIncrement;

    void setupUi(QWidget *GameDialog)
    {
        if (GameDialog->objectName().isEmpty())
            GameDialog->setObjectName("GameDialog");
        GameDialog->resize(1163, 503);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GameDialog->sizePolicy().hasHeightForWidth());
        GameDialog->setSizePolicy(sizePolicy);
        GameDialog->setMinimumSize(QSize(600, 240));
        gridLayout = new QGridLayout(GameDialog);
        gridLayout->setObjectName("gridLayout");
        player1Box = new QGroupBox(GameDialog);
        player1Box->setObjectName("player1Box");
        gridLayout_2 = new QGridLayout(player1Box);
        gridLayout_2->setObjectName("gridLayout_2");
        rbPlayer1Human = new QRadioButton(player1Box);
        rbPlayer1Human->setObjectName("rbPlayer1Human");
        rbPlayer1Human->setChecked(true);

        gridLayout_2->addWidget(rbPlayer1Human, 0, 0, 1, 1);

        rbPlayer1Engine = new QRadioButton(player1Box);
        rbPlayer1Engine->setObjectName("rbPlayer1Engine");

        gridLayout_2->addWidget(rbPlayer1Engine, 1, 0, 1, 1);

        cbPlayer1Engine = new KComboBox(player1Box);
        cbPlayer1Engine->setObjectName("cbPlayer1Engine");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(cbPlayer1Engine->sizePolicy().hasHeightForWidth());
        cbPlayer1Engine->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(cbPlayer1Engine, 1, 1, 1, 1);

        pbPlayer1Engine = new QPushButton(player1Box);
        pbPlayer1Engine->setObjectName("pbPlayer1Engine");

        gridLayout_2->addWidget(pbPlayer1Engine, 1, 2, 1, 1);


        gridLayout->addWidget(player1Box, 0, 0, 1, 1);

        colorGroup = new QGroupBox(GameDialog);
        colorGroup->setObjectName("colorGroup");
        sizePolicy.setHeightForWidth(colorGroup->sizePolicy().hasHeightForWidth());
        colorGroup->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(colorGroup);
        verticalLayout->setObjectName("verticalLayout");
        colorWhite = new QRadioButton(colorGroup);
        colorWhite->setObjectName("colorWhite");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(colorWhite->sizePolicy().hasHeightForWidth());
        colorWhite->setSizePolicy(sizePolicy2);

        verticalLayout->addWidget(colorWhite);

        colorBlack = new QRadioButton(colorGroup);
        colorBlack->setObjectName("colorBlack");
        sizePolicy2.setHeightForWidth(colorBlack->sizePolicy().hasHeightForWidth());
        colorBlack->setSizePolicy(sizePolicy2);

        verticalLayout->addWidget(colorBlack);

        colorRandom = new QRadioButton(colorGroup);
        colorRandom->setObjectName("colorRandom");
        sizePolicy2.setHeightForWidth(colorRandom->sizePolicy().hasHeightForWidth());
        colorRandom->setSizePolicy(sizePolicy2);
        colorRandom->setChecked(true);

        verticalLayout->addWidget(colorRandom);


        gridLayout->addWidget(colorGroup, 0, 1, 1, 1);

        player2Box = new QGroupBox(GameDialog);
        player2Box->setObjectName("player2Box");
        gridLayout_3 = new QGridLayout(player2Box);
        gridLayout_3->setObjectName("gridLayout_3");
        rbPlayer2Human = new QRadioButton(player2Box);
        rbPlayer2Human->setObjectName("rbPlayer2Human");
        rbPlayer2Human->setChecked(true);

        gridLayout_3->addWidget(rbPlayer2Human, 0, 0, 1, 1);

        rbPlayer2Engine = new QRadioButton(player2Box);
        rbPlayer2Engine->setObjectName("rbPlayer2Engine");

        gridLayout_3->addWidget(rbPlayer2Engine, 1, 0, 1, 1);

        cbPlayer2Engine = new KComboBox(player2Box);
        cbPlayer2Engine->setObjectName("cbPlayer2Engine");
        sizePolicy1.setHeightForWidth(cbPlayer2Engine->sizePolicy().hasHeightForWidth());
        cbPlayer2Engine->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(cbPlayer2Engine, 1, 1, 1, 1);

        pbPlayer2Engine = new QToolButton(player2Box);
        pbPlayer2Engine->setObjectName("pbPlayer2Engine");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(pbPlayer2Engine->sizePolicy().hasHeightForWidth());
        pbPlayer2Engine->setSizePolicy(sizePolicy3);

        gridLayout_3->addWidget(pbPlayer2Engine, 1, 2, 1, 1);

        rbPlayer2Server = new QRadioButton(player2Box);
        rbPlayer2Server->setObjectName("rbPlayer2Server");

        gridLayout_3->addWidget(rbPlayer2Server, 2, 0, 1, 1);

        cbPlayer2Server = new KHistoryComboBox(player2Box);
        cbPlayer2Server->setObjectName("cbPlayer2Server");
        cbPlayer2Server->setEnabled(false);

        gridLayout_3->addWidget(cbPlayer2Server, 2, 1, 1, 1);


        gridLayout->addWidget(player2Box, 1, 0, 1, 1);

        gbTimeControl = new QGroupBox(GameDialog);
        gbTimeControl->setObjectName("gbTimeControl");
        gbTimeControl->setCheckable(false);
        gbTimeControl->setChecked(false);
        gridLayout_4 = new QGridLayout(gbTimeControl);
        gridLayout_4->setObjectName("gridLayout_4");
        cbTimeControl = new QCheckBox(gbTimeControl);
        cbTimeControl->setObjectName("cbTimeControl");

        gridLayout_4->addWidget(cbTimeControl, 0, 0, 1, 1);

        lNumberOfMoves = new QLabel(gbTimeControl);
        lNumberOfMoves->setObjectName("lNumberOfMoves");

        gridLayout_4->addWidget(lNumberOfMoves, 1, 0, 1, 1);

        sbNumberOfMoves = new QSpinBox(gbTimeControl);
        sbNumberOfMoves->setObjectName("sbNumberOfMoves");
        sbNumberOfMoves->setMinimumSize(QSize(120, 0));
        sbNumberOfMoves->setMaximum(120);
        sbNumberOfMoves->setValue(40);

        gridLayout_4->addWidget(sbNumberOfMoves, 1, 1, 1, 2);

        timeLimitLabel = new QLabel(gbTimeControl);
        timeLimitLabel->setObjectName("timeLimitLabel");

        gridLayout_4->addWidget(timeLimitLabel, 2, 0, 1, 1);

        sbTimeLimit = new QSpinBox(gbTimeControl);
        sbTimeLimit->setObjectName("sbTimeLimit");
        sbTimeLimit->setMinimumSize(QSize(120, 0));
        sbTimeLimit->setMinimum(1);
        sbTimeLimit->setMaximum(300);

        gridLayout_4->addWidget(sbTimeLimit, 2, 1, 1, 2);

        timeIncrementLabel = new QLabel(gbTimeControl);
        timeIncrementLabel->setObjectName("timeIncrementLabel");

        gridLayout_4->addWidget(timeIncrementLabel, 3, 0, 1, 1);

        sbTimeIncrement = new QSpinBox(gbTimeControl);
        sbTimeIncrement->setObjectName("sbTimeIncrement");
        sbTimeIncrement->setMinimumSize(QSize(120, 0));
        sbTimeIncrement->setMaximum(900);

        gridLayout_4->addWidget(sbTimeIncrement, 3, 1, 1, 2);


        gridLayout->addWidget(gbTimeControl, 1, 1, 1, 1);

#if QT_CONFIG(shortcut)
        lNumberOfMoves->setBuddy(sbNumberOfMoves);
        timeLimitLabel->setBuddy(sbTimeLimit);
        timeIncrementLabel->setBuddy(sbTimeIncrement);
#endif // QT_CONFIG(shortcut)

        retranslateUi(GameDialog);

        QMetaObject::connectSlotsByName(GameDialog);
    } // setupUi

    void retranslateUi(QWidget *GameDialog)
    {
        player1Box->setTitle(tr2i18n("Player 1", nullptr));
        rbPlayer1Human->setText(tr2i18n("Human (&You)", nullptr));
        rbPlayer1Engine->setText(tr2i18n("&Computer engine:", nullptr));
        pbPlayer1Engine->setText(QString());
        colorGroup->setTitle(tr2i18n("Player 1's Color", nullptr));
        colorWhite->setText(tr2i18n("White", nullptr));
        colorBlack->setText(tr2i18n("B&lack", nullptr));
        colorRandom->setText(tr2i18n("Choose r&andomly", nullptr));
        player2Box->setTitle(tr2i18n("Player 2", nullptr));
        rbPlayer2Human->setText(tr2i18n("H&uman", nullptr));
        rbPlayer2Engine->setText(tr2i18n("Co&mputer engine:", nullptr));
        pbPlayer2Engine->setText(QString());
        rbPlayer2Server->setText(tr2i18n("Chess server:", nullptr));
        cbPlayer2Server->setHistoryItems(QStringList{});
        gbTimeControl->setTitle(QString());
        cbTimeControl->setText(tr2i18n("&Use time control", nullptr));
        lNumberOfMoves->setText(tr2i18n("&Time control period:", nullptr));
        sbNumberOfMoves->setSpecialValueText(tr2i18n("Timer Only", "Time control mode"));
        timeLimitLabel->setText(tr2i18n("&Initial time limit:", nullptr));
        timeIncrementLabel->setText(tr2i18n("I&ncrement per move:", nullptr));
        (void)GameDialog;
    } // retranslateUi

};

namespace Ui {
    class GameDialog: public Ui_GameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GAMEDIALOG_H

