/********************************************************************************
** Form generated from reading UI file 'prefs_base.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_BASE_H
#define UI_PREFS_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_prefs_base
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *animationGroup;
    QFormLayout *formLayout;
    QLabel *animationSpeedLabel;
    KComboBox *kcfg_animationSpeed;
    QCheckBox *kcfg_animateBoard;
    QGroupBox *appearanceGroup;
    QFormLayout *formLayout_2;
    QLabel *showMarkersForLabel;
    QCheckBox *kcfg_showMarker;
    QCheckBox *kcfg_showMotion;
    QCheckBox *kcfg_showDanger;
    QLabel *label;
    KComboBox *kcfg_borderDisplayType;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_playSounds;
    QCheckBox *kcfg_flipBoard;
    QCheckBox *kcfg_askDiscard;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *prefs_base)
    {
        if (prefs_base->objectName().isEmpty())
            prefs_base->setObjectName("prefs_base");
        prefs_base->resize(624, 501);
        verticalLayout = new QVBoxLayout(prefs_base);
        verticalLayout->setObjectName("verticalLayout");
        animationGroup = new QGroupBox(prefs_base);
        animationGroup->setObjectName("animationGroup");
        formLayout = new QFormLayout(animationGroup);
        formLayout->setObjectName("formLayout");
        animationSpeedLabel = new QLabel(animationGroup);
        animationSpeedLabel->setObjectName("animationSpeedLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, animationSpeedLabel);

        kcfg_animationSpeed = new KComboBox(animationGroup);
        kcfg_animationSpeed->addItem(QString());
        kcfg_animationSpeed->addItem(QString());
        kcfg_animationSpeed->addItem(QString());
        kcfg_animationSpeed->addItem(QString());
        kcfg_animationSpeed->setObjectName("kcfg_animationSpeed");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_animationSpeed);

        kcfg_animateBoard = new QCheckBox(animationGroup);
        kcfg_animateBoard->setObjectName("kcfg_animateBoard");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_animateBoard);


        verticalLayout->addWidget(animationGroup);

        appearanceGroup = new QGroupBox(prefs_base);
        appearanceGroup->setObjectName("appearanceGroup");
        formLayout_2 = new QFormLayout(appearanceGroup);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        showMarkersForLabel = new QLabel(appearanceGroup);
        showMarkersForLabel->setObjectName("showMarkersForLabel");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, showMarkersForLabel);

        kcfg_showMarker = new QCheckBox(appearanceGroup);
        kcfg_showMarker->setObjectName("kcfg_showMarker");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_showMarker);

        kcfg_showMotion = new QCheckBox(appearanceGroup);
        kcfg_showMotion->setObjectName("kcfg_showMotion");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_showMotion->sizePolicy().hasHeightForWidth());
        kcfg_showMotion->setSizePolicy(sizePolicy);
        kcfg_showMotion->setChecked(true);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_showMotion);

        kcfg_showDanger = new QCheckBox(appearanceGroup);
        kcfg_showDanger->setObjectName("kcfg_showDanger");
        kcfg_showDanger->setChecked(true);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_showDanger);

        label = new QLabel(appearanceGroup);
        label->setObjectName("label");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label);

        kcfg_borderDisplayType = new KComboBox(appearanceGroup);
        kcfg_borderDisplayType->addItem(QString());
        kcfg_borderDisplayType->addItem(QString());
        kcfg_borderDisplayType->addItem(QString());
        kcfg_borderDisplayType->setObjectName("kcfg_borderDisplayType");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_borderDisplayType);


        verticalLayout->addWidget(appearanceGroup);

        groupBox = new QGroupBox(prefs_base);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_playSounds = new QCheckBox(groupBox);
        kcfg_playSounds->setObjectName("kcfg_playSounds");

        verticalLayout_2->addWidget(kcfg_playSounds);

        kcfg_flipBoard = new QCheckBox(groupBox);
        kcfg_flipBoard->setObjectName("kcfg_flipBoard");

        verticalLayout_2->addWidget(kcfg_flipBoard);

        kcfg_askDiscard = new QCheckBox(groupBox);
        kcfg_askDiscard->setObjectName("kcfg_askDiscard");

        verticalLayout_2->addWidget(kcfg_askDiscard);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 133, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        animationSpeedLabel->setBuddy(kcfg_animationSpeed);
        showMarkersForLabel->setBuddy(kcfg_showMarker);
#endif // QT_CONFIG(shortcut)

        retranslateUi(prefs_base);

        QMetaObject::connectSlotsByName(prefs_base);
    } // setupUi

    void retranslateUi(QWidget *prefs_base)
    {
        animationGroup->setTitle(tr2i18n("Animations", nullptr));
        animationSpeedLabel->setText(tr2i18n("&Animation speed:", nullptr));
        kcfg_animationSpeed->setItemText(0, tr2i18n("Instant (no animation)", nullptr));
        kcfg_animationSpeed->setItemText(1, tr2i18n("Fast", nullptr));
        kcfg_animationSpeed->setItemText(2, tr2i18n("Normal", nullptr));
        kcfg_animationSpeed->setItemText(3, tr2i18n("Slow", nullptr));

        kcfg_animateBoard->setText(tr2i18n("Animate the board as well", nullptr));
        appearanceGroup->setTitle(tr2i18n("Appearance", nullptr));
        showMarkersForLabel->setText(tr2i18n("Show &markers for:", nullptr));
        kcfg_showMarker->setText(tr2i18n("Legal moves", "Option to show markers for"));
        kcfg_showMotion->setText(tr2i18n("Opponent's move", "Option to show markers for"));
        kcfg_showDanger->setText(tr2i18n("Check", "Option to show markers for"));
        label->setText(tr2i18n("Border display:", nullptr));
        kcfg_borderDisplayType->setItemText(0, tr2i18n("No borders", nullptr));
        kcfg_borderDisplayType->setItemText(1, tr2i18n("Only borders", nullptr));
        kcfg_borderDisplayType->setItemText(2, tr2i18n("Borders and notation", nullptr));

        groupBox->setTitle(tr2i18n("Behavior", nullptr));
        kcfg_playSounds->setText(tr2i18n("Play sounds", nullptr));
        kcfg_flipBoard->setText(tr2i18n("Flip the board in local matches between humans", nullptr));
        kcfg_askDiscard->setText(tr2i18n("Show confirmation dialog before closing", nullptr));
        (void)prefs_base;
    } // retranslateUi

};

namespace Ui {
    class prefs_base: public Ui_prefs_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_BASE_H

