/********************************************************************************
** Form generated from reading UI file 'clockwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLOCKWIDGET_H
#define UI_CLOCKWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <clock.h>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ClockWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupB;
    QVBoxLayout *verticalLayout_2;
    Knights::Clock *clockB;
    QProgressBar *progressB;
    QGroupBox *groupW;
    QVBoxLayout *verticalLayout_3;
    Knights::Clock *clockW;
    QProgressBar *progressW;

    void setupUi(QWidget *ClockWidget)
    {
        if (ClockWidget->objectName().isEmpty())
            ClockWidget->setObjectName("ClockWidget");
        ClockWidget->resize(243, 660);
        verticalLayout = new QVBoxLayout(ClockWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupB = new QGroupBox(ClockWidget);
        groupB->setObjectName("groupB");
        verticalLayout_2 = new QVBoxLayout(groupB);
        verticalLayout_2->setObjectName("verticalLayout_2");
        clockB = new Knights::Clock(groupB);
        clockB->setObjectName("clockB");

        verticalLayout_2->addWidget(clockB);

        progressB = new QProgressBar(groupB);
        progressB->setObjectName("progressB");
        QFont font;
        font.setPointSize(24);
        progressB->setFont(font);
        progressB->setValue(24);
        progressB->setInvertedAppearance(true);

        verticalLayout_2->addWidget(progressB);


        verticalLayout->addWidget(groupB);

        groupW = new QGroupBox(ClockWidget);
        groupW->setObjectName("groupW");
        verticalLayout_3 = new QVBoxLayout(groupW);
        verticalLayout_3->setObjectName("verticalLayout_3");
        clockW = new Knights::Clock(groupW);
        clockW->setObjectName("clockW");

        verticalLayout_3->addWidget(clockW);

        progressW = new QProgressBar(groupW);
        progressW->setObjectName("progressW");
        progressW->setFont(font);
        progressW->setValue(24);
        progressW->setInvertedAppearance(true);

        verticalLayout_3->addWidget(progressW);


        verticalLayout->addWidget(groupW);


        retranslateUi(ClockWidget);

        QMetaObject::connectSlotsByName(ClockWidget);
    } // setupUi

    void retranslateUi(QWidget *ClockWidget)
    {
        groupB->setTitle(tr2i18n("Black", nullptr));
        groupW->setTitle(tr2i18n("White", nullptr));
        (void)ClockWidget;
    } // retranslateUi

};

namespace Ui {
    class ClockWidget: public Ui_ClockWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CLOCKWIDGET_H

