/********************************************************************************
** Form generated from reading UI file 'prefs_access.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_ACCESS_H
#define UI_PREFS_ACCESS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_prefs_access
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *external_box;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_speakOpponentsMoves;
    QCheckBox *kcfg_allowExternalControl;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *prefs_access)
    {
        if (prefs_access->objectName().isEmpty())
            prefs_access->setObjectName("prefs_access");
        prefs_access->resize(455, 260);
        verticalLayout = new QVBoxLayout(prefs_access);
        verticalLayout->setObjectName("verticalLayout");
        external_box = new QGroupBox(prefs_access);
        external_box->setObjectName("external_box");
        verticalLayout_2 = new QVBoxLayout(external_box);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_speakOpponentsMoves = new QCheckBox(external_box);
        kcfg_speakOpponentsMoves->setObjectName("kcfg_speakOpponentsMoves");

        verticalLayout_2->addWidget(kcfg_speakOpponentsMoves);

        kcfg_allowExternalControl = new QCheckBox(external_box);
        kcfg_allowExternalControl->setObjectName("kcfg_allowExternalControl");

        verticalLayout_2->addWidget(kcfg_allowExternalControl);


        verticalLayout->addWidget(external_box);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(prefs_access);

        QMetaObject::connectSlotsByName(prefs_access);
    } // setupUi

    void retranslateUi(QWidget *prefs_access)
    {
        external_box->setTitle(tr2i18n("External Programs", nullptr));
        kcfg_speakOpponentsMoves->setText(tr2i18n("Speak opponent's moves", nullptr));
        kcfg_allowExternalControl->setText(tr2i18n("Allow other programs to control Knights", nullptr));
        (void)prefs_access;
    } // retranslateUi

};

namespace Ui {
    class prefs_access: public Ui_prefs_access {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_ACCESS_H

