/********************************************************************************
** Form generated from reading UI file 'enginesettings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENGINESETTINGS_H
#define UI_ENGINESETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EngineSettings
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *autoDetectButton;
    QSpacerItem *horizontalSpacer;
    QPushButton *addButton;
    QPushButton *removeButton;
    QTableWidget *tableWidget;

    void setupUi(QWidget *EngineSettings)
    {
        if (EngineSettings->objectName().isEmpty())
            EngineSettings->setObjectName("EngineSettings");
        EngineSettings->resize(682, 240);
        verticalLayout = new QVBoxLayout(EngineSettings);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        autoDetectButton = new QPushButton(EngineSettings);
        autoDetectButton->setObjectName("autoDetectButton");

        horizontalLayout->addWidget(autoDetectButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        addButton = new QPushButton(EngineSettings);
        addButton->setObjectName("addButton");

        horizontalLayout->addWidget(addButton);

        removeButton = new QPushButton(EngineSettings);
        removeButton->setObjectName("removeButton");

        horizontalLayout->addWidget(removeButton);


        verticalLayout->addLayout(horizontalLayout);

        tableWidget = new QTableWidget(EngineSettings);
        if (tableWidget->columnCount() < 4)
            tableWidget->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        tableWidget->setObjectName("tableWidget");
        tableWidget->setAlternatingRowColors(true);
        tableWidget->setSelectionMode(QAbstractItemView::SingleSelection);
        tableWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableWidget->setColumnCount(4);
        tableWidget->horizontalHeader()->setStretchLastSection(true);

        verticalLayout->addWidget(tableWidget);


        retranslateUi(EngineSettings);

        QMetaObject::connectSlotsByName(EngineSettings);
    } // setupUi

    void retranslateUi(QWidget *EngineSettings)
    {
        autoDetectButton->setText(tr2i18n("Auto detect", nullptr));
        addButton->setText(tr2i18n("Add", nullptr));
        removeButton->setText(tr2i18n("Remove", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Command", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidget->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Protocol", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = tableWidget->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Installed", nullptr));
        (void)EngineSettings;
    } // retranslateUi

};

namespace Ui {
    class EngineSettings: public Ui_EngineSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ENGINESETTINGS_H

