/****************************************************************************
** Meta object code from reading C++ file 'ficsdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../knights-26.07.80/src/proto/ficsdialog.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ficsdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Knights10FicsDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Knights::FicsDialog::qt_create_metaobjectdata<qt_meta_tag_ZN7Knights10FicsDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Knights::FicsDialog",
        "login",
        "",
        "username",
        "password",
        "seekingChanged",
        "seek",
        "declineButtonNeeded",
        "needed",
        "acceptButtonNeeded",
        "acceptSeek",
        "seekId",
        "acceptChallenge",
        "challengeId",
        "declineChallenge",
        "slotSessionStarted",
        "addGameOffer",
        "FicsGameOffer",
        "offer",
        "removeGameOffer",
        "id",
        "addChallenge",
        "FicsChallenge",
        "challenge",
        "removeChallenge",
        "clearOffers",
        "accept",
        "decline",
        "currentTabChanged",
        "tab",
        "slotCreateAccount",
        "slotLogin",
        "setConsoleWidget",
        "QWidget*",
        "widget",
        "focusOnLogin",
        "setStatus",
        "status",
        "error",
        "setLoginEnabled",
        "enable",
        "rememberCheckBoxChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'login'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'seekingChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'declineButtonNeeded'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'acceptButtonNeeded'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'acceptSeek'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'acceptChallenge'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'declineChallenge'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'slotSessionStarted'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addGameOffer'
        QtMocHelpers::SlotData<void(const FicsGameOffer &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'removeGameOffer'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'addChallenge'
        QtMocHelpers::SlotData<void(const FicsChallenge &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'removeChallenge'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'clearOffers'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'decline'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'currentTabChanged'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'slotCreateAccount'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLogin'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setConsoleWidget'
        QtMocHelpers::SlotData<void(QWidget *)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'focusOnLogin'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setStatus'
        QtMocHelpers::SlotData<void(const QString &, bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::Bool, 38 },
        }}),
        // Slot 'setStatus'
        QtMocHelpers::SlotData<void(const QString &)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'setLoginEnabled'
        QtMocHelpers::SlotData<void(bool)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'rememberCheckBoxChanged'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FicsDialog, qt_meta_tag_ZN7Knights10FicsDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Knights::FicsDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights10FicsDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights10FicsDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Knights10FicsDialogE_t>.metaTypes,
    nullptr
} };

void Knights::FicsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FicsDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->login((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->seekingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->declineButtonNeeded((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->acceptButtonNeeded((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->acceptSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->acceptChallenge((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->declineChallenge((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->slotSessionStarted(); break;
        case 8: _t->addGameOffer((*reinterpret_cast<std::add_pointer_t<FicsGameOffer>>(_a[1]))); break;
        case 9: _t->removeGameOffer((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->addChallenge((*reinterpret_cast<std::add_pointer_t<FicsChallenge>>(_a[1]))); break;
        case 11: _t->removeChallenge((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->clearOffers(); break;
        case 13: _t->accept(); break;
        case 14: _t->decline(); break;
        case 15: _t->currentTabChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->slotCreateAccount(); break;
        case 17: _t->slotLogin(); break;
        case 18: _t->setConsoleWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 19: _t->focusOnLogin(); break;
        case 20: _t->setStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 21: _t->setStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setLoginEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->rememberCheckBoxChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FicsDialog::*)(const QString & , const QString & )>(_a, &FicsDialog::login, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsDialog::*)(bool )>(_a, &FicsDialog::seekingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsDialog::*)(bool )>(_a, &FicsDialog::declineButtonNeeded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsDialog::*)(bool )>(_a, &FicsDialog::acceptButtonNeeded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsDialog::*)(int )>(_a, &FicsDialog::acceptSeek, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsDialog::*)(int )>(_a, &FicsDialog::acceptChallenge, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsDialog::*)(int )>(_a, &FicsDialog::declineChallenge, 6))
            return;
    }
}

const QMetaObject *Knights::FicsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Knights::FicsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights10FicsDialogE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Knights::FicsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void Knights::FicsDialog::login(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Knights::FicsDialog::seekingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Knights::FicsDialog::declineButtonNeeded(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Knights::FicsDialog::acceptButtonNeeded(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Knights::FicsDialog::acceptSeek(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Knights::FicsDialog::acceptChallenge(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Knights::FicsDialog::declineChallenge(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
