/********************************************************************************
** Form generated from reading UI file 'ficsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FICSDIALOG_H
#define UI_FICSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "proto/seekgraph.h"

QT_BEGIN_NAMESPACE

class Ui_FicsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *accountTab;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *logInGroup;
    QGridLayout *gridLayout_2;
    QLabel *logInStatusLabel;
    QLabel *usernameLabel;
    KLineEdit *usernameLineEdit;
    QCheckBox *registeredCheckBox;
    QLabel *passwordLabel;
    KLineEdit *passwordLineEdit;
    QCheckBox *rememberCheckBox;
    QPushButton *logInButton;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *registerButton;
    QSpacerItem *verticalSpacer;
    QWidget *joinTab;
    QVBoxLayout *verticalLayout_2;
    QTableWidget *offerTable;
    QWidget *graphTab;
    QVBoxLayout *verticalLayout_5;
    Knights::SeekGraph *graphView;
    QWidget *challengeTab;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *ratedCheckBox;
    QCheckBox *autoCheckBox;
    QPushButton *seekButton;
    QListView *challengeListView;
    QWidget *consoleTab;
    QVBoxLayout *verticalLayout_4;

    void setupUi(QWidget *FicsDialog)
    {
        if (FicsDialog->objectName().isEmpty())
            FicsDialog->setObjectName("FicsDialog");
        FicsDialog->resize(568, 269);
        verticalLayout = new QVBoxLayout(FicsDialog);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(FicsDialog);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setEnabled(true);
        tabWidget->setMovable(true);
        accountTab = new QWidget();
        accountTab->setObjectName("accountTab");
        accountTab->setEnabled(true);
        verticalLayout_3 = new QVBoxLayout(accountTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        logInGroup = new QGroupBox(accountTab);
        logInGroup->setObjectName("logInGroup");
        gridLayout_2 = new QGridLayout(logInGroup);
        gridLayout_2->setObjectName("gridLayout_2");
        logInStatusLabel = new QLabel(logInGroup);
        logInStatusLabel->setObjectName("logInStatusLabel");

        gridLayout_2->addWidget(logInStatusLabel, 0, 0, 1, 5);

        usernameLabel = new QLabel(logInGroup);
        usernameLabel->setObjectName("usernameLabel");

        gridLayout_2->addWidget(usernameLabel, 1, 0, 1, 1);

        usernameLineEdit = new KLineEdit(logInGroup);
        usernameLineEdit->setObjectName("usernameLineEdit");
        usernameLineEdit->setProperty("showClearButton", QVariant(true));

        gridLayout_2->addWidget(usernameLineEdit, 1, 1, 1, 3);

        registeredCheckBox = new QCheckBox(logInGroup);
        registeredCheckBox->setObjectName("registeredCheckBox");
        registeredCheckBox->setChecked(true);

        gridLayout_2->addWidget(registeredCheckBox, 1, 4, 1, 1);

        passwordLabel = new QLabel(logInGroup);
        passwordLabel->setObjectName("passwordLabel");

        gridLayout_2->addWidget(passwordLabel, 2, 0, 1, 1);

        passwordLineEdit = new KLineEdit(logInGroup);
        passwordLineEdit->setObjectName("passwordLineEdit");
        passwordLineEdit->setProperty("showClearButton", QVariant(true));
        passwordLineEdit->setEchoMode(QLineEdit::Password);

        gridLayout_2->addWidget(passwordLineEdit, 2, 1, 1, 3);

        rememberCheckBox = new QCheckBox(logInGroup);
        rememberCheckBox->setObjectName("rememberCheckBox");

        gridLayout_2->addWidget(rememberCheckBox, 2, 4, 1, 1);

        logInButton = new QPushButton(logInGroup);
        logInButton->setObjectName("logInButton");

        gridLayout_2->addWidget(logInButton, 3, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 3, 2, 1, 1);

        registerButton = new QPushButton(logInGroup);
        registerButton->setObjectName("registerButton");

        gridLayout_2->addWidget(registerButton, 3, 3, 1, 1);


        verticalLayout_3->addWidget(logInGroup);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        tabWidget->addTab(accountTab, QString());
        joinTab = new QWidget();
        joinTab->setObjectName("joinTab");
        verticalLayout_2 = new QVBoxLayout(joinTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        offerTable = new QTableWidget(joinTab);
        if (offerTable->columnCount() < 7)
            offerTable->setColumnCount(7);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        offerTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        offerTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        offerTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        offerTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        offerTable->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        offerTable->setHorizontalHeaderItem(5, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        offerTable->setHorizontalHeaderItem(6, __qtablewidgetitem6);
        offerTable->setObjectName("offerTable");
        offerTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        offerTable->setProperty("showDropIndicator", QVariant(false));
        offerTable->setDragDropOverwriteMode(false);
        offerTable->setAlternatingRowColors(true);
        offerTable->setSelectionMode(QAbstractItemView::SingleSelection);
        offerTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        offerTable->setSortingEnabled(true);
        offerTable->horizontalHeader()->setCascadingSectionResizes(true);
        offerTable->horizontalHeader()->setProperty("showSortIndicator", QVariant(true));
        offerTable->horizontalHeader()->setStretchLastSection(true);
        offerTable->verticalHeader()->setVisible(false);
        offerTable->verticalHeader()->setHighlightSections(false);

        verticalLayout_2->addWidget(offerTable);

        tabWidget->addTab(joinTab, QString());
        graphTab = new QWidget();
        graphTab->setObjectName("graphTab");
        verticalLayout_5 = new QVBoxLayout(graphTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        graphView = new Knights::SeekGraph(graphTab);
        graphView->setObjectName("graphView");
        graphView->setFrameShape(QFrame::StyledPanel);
        graphView->setFrameShadow(QFrame::Raised);

        verticalLayout_5->addWidget(graphView);

        tabWidget->addTab(graphTab, QString());
        challengeTab = new QWidget();
        challengeTab->setObjectName("challengeTab");
        verticalLayout_6 = new QVBoxLayout(challengeTab);
        verticalLayout_6->setObjectName("verticalLayout_6");
        ratedCheckBox = new QCheckBox(challengeTab);
        ratedCheckBox->setObjectName("ratedCheckBox");

        verticalLayout_6->addWidget(ratedCheckBox);

        autoCheckBox = new QCheckBox(challengeTab);
        autoCheckBox->setObjectName("autoCheckBox");

        verticalLayout_6->addWidget(autoCheckBox);

        seekButton = new QPushButton(challengeTab);
        seekButton->setObjectName("seekButton");
        seekButton->setCheckable(true);

        verticalLayout_6->addWidget(seekButton);

        challengeListView = new QListView(challengeTab);
        challengeListView->setObjectName("challengeListView");

        verticalLayout_6->addWidget(challengeListView);

        tabWidget->addTab(challengeTab, QString());
        consoleTab = new QWidget();
        consoleTab->setObjectName("consoleTab");
        verticalLayout_4 = new QVBoxLayout(consoleTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        tabWidget->addTab(consoleTab, QString());

        verticalLayout->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        usernameLabel->setBuddy(usernameLineEdit);
        passwordLabel->setBuddy(passwordLineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(FicsDialog);
        QObject::connect(registeredCheckBox, SIGNAL(toggled(bool)), passwordLineEdit, SLOT(setEnabled(bool)));
        QObject::connect(registeredCheckBox, &QCheckBox::toggled, ratedCheckBox, &QCheckBox::setEnabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(FicsDialog);
    } // setupUi

    void retranslateUi(QWidget *FicsDialog)
    {
        logInGroup->setTitle(QString());
        logInStatusLabel->setText(QString());
        usernameLabel->setText(tr2i18n("&Username:", nullptr));
        registeredCheckBox->setText(tr2i18n("This is a registered account", nullptr));
        passwordLabel->setText(tr2i18n("&Password:", nullptr));
        rememberCheckBox->setText(tr2i18n("Log me in automatically", nullptr));
        logInButton->setText(tr2i18n("Log in", nullptr));
        registerButton->setText(tr2i18n("Create an account", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(accountTab), tr2i18n("Account", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(accountTab), tr2i18n("Log in to the chess server", nullptr));
#endif // QT_CONFIG(tooltip)
        QTableWidgetItem *___qtablewidgetitem = offerTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Player", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = offerTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Rating", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = offerTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Time", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = offerTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Increment", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = offerTable->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(tr2i18n("Rated", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = offerTable->horizontalHeaderItem(5);
        ___qtablewidgetitem5->setText(tr2i18n("Variant", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = offerTable->horizontalHeaderItem(6);
        ___qtablewidgetitem6->setText(tr2i18n("Your color", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(joinTab), tr2i18n("Seek List", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(joinTab), tr2i18n("Current ads arranged in a list", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(graphTab), tr2i18n("Seek Graph", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(graphTab), tr2i18n("Current ads arranged by rating and duration", nullptr));
#endif // QT_CONFIG(tooltip)
        ratedCheckBox->setText(tr2i18n("Rated match", nullptr));
        autoCheckBox->setText(tr2i18n("Automatically start the game", nullptr));
        seekButton->setText(tr2i18n("Seek", "Start searching for opponents"));
        tabWidget->setTabText(tabWidget->indexOf(challengeTab), tr2i18n("Challenges", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(challengeTab), tr2i18n("Post an ad for other players", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(consoleTab), tr2i18n("Console", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(consoleTab), tr2i18n("Use custom commands", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)FicsDialog;
    } // retranslateUi

};

namespace Ui {
    class FicsDialog: public Ui_FicsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FICSDIALOG_H

