/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.12.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // knightsui.rc
  0x0,0x0,0x1,0xeb,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xf8,0x5,0xd,0xf,0x0,0xc6,0x94,0x40,0x1f,0x40,0x93,0x1b,
  0x13,0x9b,0xb4,0x91,0x92,0x80,0x30,0x49,0x4f,0xa5,0x90,0x9,0xc5,0xc5,0x18,0xd7,
  0xd7,0x1e,0x9f,0x74,0x4b,0x4a,0x99,0x45,0xf1,0xd3,0x2c,0x2,0x39,0x0,0x38,0x0,
  0x35,0x0,0x92,0xfa,0xc3,0xb1,0x7a,0xb2,0x2c,0x7b,0xef,0x70,0xd5,0x4a,0xb9,0xe8,
  0x27,0xa1,0x39,0xee,0x2b,0x25,0x7b,0x56,0x2e,0xe2,0xcb,0xce,0xd6,0x98,0x84,0x1c,
  0x9,0xe1,0xc,0x1,0x46,0x44,0xe2,0x22,0x39,0x3b,0x3a,0x9c,0xdc,0x9c,0xe0,0x19,
  0xb8,0x68,0x7a,0x3f,0xe5,0x4c,0xb3,0x2e,0x1a,0x4,0x14,0xaf,0xb9,0x8c,0xe7,0x4,
  0x13,0x4e,0x4a,0x74,0x15,0xd8,0xe4,0x7,0xe4,0x48,0xcd,0xc5,0xd7,0x3c,0xcd,0x99,
  0xde,0x75,0xa1,0x3b,0xfe,0xd0,0xcf,0x70,0x76,0x60,0x2f,0x4c,0x41,0x88,0xe3,0x41,
  0x79,0x3,0x81,0x80,0x50,0xc8,0xfa,0x35,0x87,0xd7,0x98,0xac,0xde,0x47,0xba,0x71,
  0x6e,0xfd,0x17,0xd4,0x94,0x39,0xf5,0x2f,0x67,0xd7,0xca,0xcf,0xf4,0x35,0xe7,0x71,
  0x62,0xd3,0x83,0x1e,0x52,0xd5,0x70,0xcd,0xf8,0xc5,0x91,0x5e,0x63,0x18,0xea,0x75,
  0xe9,0x5e,0xc,0x1,0x54,0xea,0x15,0x8a,0xb9,0x25,0xee,0x94,0xfd,0x4c,0x97,0xc6,
  0x89,0xdf,0x2f,0xa7,0x17,0x3f,0xb6,0x57,0x8e,0xd4,0x98,0x7c,0x50,0xe6,0x71,0xf6,
  0xa4,0xb1,0x55,0xd9,0x45,0x5,0x3d,0x2,0x12,0xad,0xf1,0xfb,0x20,0xce,0xec,0xc7,
  0x75,0x8b,0x6e,0xa5,0xcd,0x5e,0xcb,0x3d,0xf2,0x20,0xae,0x4d,0x65,0x15,0x5c,0xab,
  0x32,0xb1,0xe5,0x3f,0xbd,0x2e,0x55,0x41,0xb7,0xe0,0x86,0x7a,0xfd,0xe,0x5d,0xa0,
  0xd1,0x21,0x44,0x36,0x23,0x2a,0x48,0x69,0x67,0xc,0x20,0x84,0x10,0x46,0x11,0xf1,
  0x11,0x98,0xbd,0xc8,0x63,0xc6,0x95,0x36,0xb6,0xd9,0x91,0xe6,0xc7,0x6d,0xe,0x29,
  0x2c,0xe1,0x0,0xc6,0x6f,0xdf,0x28,0x34,0x3c,0xb3,0x1e,0x92,0x9a,0xe4,0xd4,0x28,
  0xd3,0xb0,0x3c,0x27,0xe6,0x36,0x2f,0xc7,0x5c,0xc7,0x9a,0x3c,0x6a,0xcb,0x59,0x41,
  0xc0,0x52,0x6,0x14,0x53,0xcc,0xe5,0xad,0x77,0xdb,0xb5,0x5a,0x5d,0x19,0x72,0x6b,
  0xc4,0x10,0xa8,0xd5,0x4a,0x63,0xc4,0x53,0xf6,0x2,0x2c,0x10,0xf0,0xa6,0x57,0x3,
  0x56,0xb2,0x12,0x13,0xe,0x2,0xd1,0xc5,0x23,0x21,0xc6,0x3a,0x6d,0x76,0x3d,0x54,
  0x68,0xb2,0xb9,0x81,0x1e,0xbe,0x50,0x1,0xe4,0x89,0xba,0x81,0xee,0xb9,0xba,0x14,
  0x58,0x78,0xe1,0xd8,0x84,0x13,0x9a,0x71,0x70,0x60,0x58,0xc3,0x26,0xe,0x88,0x65,
  0x11,0xf0,0x81,0x8c,0xd7,0xee,0x80,0x2,0xd7,0x1e,0x87,0x5c,0x7c,0xe1,0x97,0xec,
  0x64,0x5e,0x4c,0x72,0xe0,0x1c,0x81,0xcd,0x32,0xa4,0x3a,0x3,0x4b,0x1,0x1f,0xe7,
  0xa1,0x32,0xc4,0x1,0xbe,0x62,0xe0,0x4b,0x5c,0xd4,0x92,0x18,0x1c,0x3,0x82,0xe9,
  0xdb,0xfd,0x3e,0xdc,0xb8,0x9e,0x23,0xb0,0x7f,0x9c,0xcf,0x29,0xe,0xd0,0x85,0xe,
  0x90,0xc,0x82,0xce,0xfa,0xda,0x12,0x6,0x40,0x15,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // knights
  0x0,0x7,
  0x2,0x4f,0xdf,0x53,
  0x0,0x6b,
  0x0,0x6e,0x0,0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,0x73,
    // knightsui.rc
  0x0,0xc,
  0x5,0xe2,0x7e,0x63,
  0x0,0x6b,
  0x0,0x6e,0x0,0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,0x73,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x70,0xc0,0x2f,0x18,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x70,0xc0,0x2f,0x18,
  // :/kxmlgui5/knights
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x70,0xc0,0x2f,0x18,
  // :/kxmlgui5/knights/knightsui.rc
  0x0,0x0,0x0,0x2a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x70,0xc0,0x2f,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_knights)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_knights)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_knights)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_knights)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_knights)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_knights)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
