/********************************************************************************
** Form generated from reading UI file 'historywidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HISTORYWIDGET_H
#define UI_HISTORYWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_HistoryWidget
{
public:
    QVBoxLayout *verticalLayout;
    QTableWidget *twMoves;
    QFormLayout *formLayout;
    QLabel *notationLabel;
    QComboBox *notationComboBox;

    void setupUi(QWidget *HistoryWidget)
    {
        if (HistoryWidget->objectName().isEmpty())
            HistoryWidget->setObjectName("HistoryWidget");
        HistoryWidget->resize(541, 300);
        verticalLayout = new QVBoxLayout(HistoryWidget);
        verticalLayout->setObjectName("verticalLayout");
        twMoves = new QTableWidget(HistoryWidget);
        if (twMoves->columnCount() < 2)
            twMoves->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        twMoves->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        twMoves->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        twMoves->setObjectName("twMoves");
        twMoves->setAutoScroll(false);
        twMoves->setEditTriggers(QAbstractItemView::NoEditTriggers);
        twMoves->setAlternatingRowColors(true);
        twMoves->setShowGrid(false);
        twMoves->horizontalHeader()->setVisible(true);
        twMoves->horizontalHeader()->setCascadingSectionResizes(true);
        twMoves->horizontalHeader()->setStretchLastSection(false);

        verticalLayout->addWidget(twMoves);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        notationLabel = new QLabel(HistoryWidget);
        notationLabel->setObjectName("notationLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, notationLabel);

        notationComboBox = new QComboBox(HistoryWidget);
        notationComboBox->addItem(QString());
        notationComboBox->addItem(QString());
        notationComboBox->addItem(QString());
        notationComboBox->setObjectName("notationComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, notationComboBox);


        verticalLayout->addLayout(formLayout);

#if QT_CONFIG(shortcut)
        notationLabel->setBuddy(notationComboBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(HistoryWidget);

        QMetaObject::connectSlotsByName(HistoryWidget);
    } // setupUi

    void retranslateUi(QWidget *HistoryWidget)
    {
        QTableWidgetItem *___qtablewidgetitem = twMoves->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("New Column", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = twMoves->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("New Column", nullptr));
        notationLabel->setText(tr2i18n("&Notation:", nullptr));
        notationComboBox->setItemText(0, tr2i18n("Short Algebraic", nullptr));
        notationComboBox->setItemText(1, tr2i18n("Long Algebraic", nullptr));
        notationComboBox->setItemText(2, tr2i18n("Coordinate", nullptr));

        (void)HistoryWidget;
    } // retranslateUi

};

namespace Ui {
    class HistoryWidget: public Ui_HistoryWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // HISTORYWIDGET_H

