/****************************************************************************
** Meta object code from reading C++ file 'ficsprotocol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../knights-26.07.80/src/proto/ficsprotocol.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ficsprotocol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Knights12FicsProtocolE_t {};
} // unnamed namespace

template <> constexpr inline auto Knights::FicsProtocol::qt_create_metaobjectdata<qt_meta_tag_ZN7Knights12FicsProtocolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Knights::FicsProtocol",
        "sessionStarted",
        "",
        "clearSeeks",
        "gameOfferRemoved",
        "id",
        "gameOfferReceived",
        "FicsGameOffer",
        "offer",
        "challengeReceived",
        "FicsChallenge",
        "challenge",
        "challengeRemoved",
        "init",
        "resign",
        "socketError",
        "dialogRejected",
        "acceptSeek",
        "acceptChallenge",
        "declineChallenge",
        "login",
        "username",
        "password",
        "sendChat",
        "text",
        "openGameDialog",
        "setSeeking",
        "seek",
        "setupOptions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sessionStarted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearSeeks'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gameOfferRemoved'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'gameOfferReceived'
        QtMocHelpers::SignalData<void(const FicsGameOffer &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'challengeReceived'
        QtMocHelpers::SignalData<void(const FicsChallenge &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'challengeRemoved'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resign'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'socketError'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dialogRejected'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'acceptSeek'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'acceptChallenge'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'declineChallenge'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'login'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'sendChat'
        QtMocHelpers::SlotData<void(QString)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'openGameDialog'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSeeking'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setupOptions'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FicsProtocol, qt_meta_tag_ZN7Knights12FicsProtocolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Knights::FicsProtocol::staticMetaObject = { {
    QMetaObject::SuperData::link<TextProtocol::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights12FicsProtocolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights12FicsProtocolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Knights12FicsProtocolE_t>.metaTypes,
    nullptr
} };

void Knights::FicsProtocol::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FicsProtocol *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sessionStarted(); break;
        case 1: _t->clearSeeks(); break;
        case 2: _t->gameOfferRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->gameOfferReceived((*reinterpret_cast<std::add_pointer_t<FicsGameOffer>>(_a[1]))); break;
        case 4: _t->challengeReceived((*reinterpret_cast<std::add_pointer_t<FicsChallenge>>(_a[1]))); break;
        case 5: _t->challengeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->init(); break;
        case 7: _t->resign(); break;
        case 8: _t->socketError(); break;
        case 9: _t->dialogRejected(); break;
        case 10: _t->acceptSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->acceptChallenge((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->declineChallenge((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->login((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->sendChat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->openGameDialog(); break;
        case 16: _t->setSeeking((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->setupOptions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FicsProtocol::*)()>(_a, &FicsProtocol::sessionStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsProtocol::*)()>(_a, &FicsProtocol::clearSeeks, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsProtocol::*)(int )>(_a, &FicsProtocol::gameOfferRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsProtocol::*)(const FicsGameOffer & )>(_a, &FicsProtocol::gameOfferReceived, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsProtocol::*)(const FicsChallenge & )>(_a, &FicsProtocol::challengeReceived, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FicsProtocol::*)(int )>(_a, &FicsProtocol::challengeRemoved, 5))
            return;
    }
}

const QMetaObject *Knights::FicsProtocol::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Knights::FicsProtocol::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights12FicsProtocolE_t>.strings))
        return static_cast<void*>(this);
    return TextProtocol::qt_metacast(_clname);
}

int Knights::FicsProtocol::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TextProtocol::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Knights::FicsProtocol::sessionStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Knights::FicsProtocol::clearSeeks()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Knights::FicsProtocol::gameOfferRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Knights::FicsProtocol::gameOfferReceived(const FicsGameOffer & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Knights::FicsProtocol::challengeReceived(const FicsChallenge & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Knights::FicsProtocol::challengeRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
