/********************************************************************************
** Form generated from reading UI file 'popup.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_POPUP_H
#define UI_POPUP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Popup
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QPushButton *acceptButton;
    QPushButton *declineButton;
    QPushButton *closeButton;

    void setupUi(QWidget *Popup)
    {
        if (Popup->objectName().isEmpty())
            Popup->setObjectName("Popup");
        Popup->resize(584, 33);
        horizontalLayout = new QHBoxLayout(Popup);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(Popup);
        label->setObjectName("label");
        label->setText(QString::fromUtf8("TextLabel"));

        horizontalLayout->addWidget(label);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        acceptButton = new QPushButton(Popup);
        acceptButton->setObjectName("acceptButton");

        horizontalLayout->addWidget(acceptButton);

        declineButton = new QPushButton(Popup);
        declineButton->setObjectName("declineButton");

        horizontalLayout->addWidget(declineButton);

        closeButton = new QPushButton(Popup);
        closeButton->setObjectName("closeButton");

        horizontalLayout->addWidget(closeButton);


        retranslateUi(Popup);

        QMetaObject::connectSlotsByName(Popup);
    } // setupUi

    void retranslateUi(QWidget *Popup)
    {
        acceptButton->setText(tr2i18n("Accept", nullptr));
        declineButton->setText(tr2i18n("Decline", nullptr));
        closeButton->setText(tr2i18n("Close", nullptr));
        (void)Popup;
    } // retranslateUi

};

namespace Ui {
    class Popup: public Ui_Popup {};
} // namespace Ui

QT_END_NAMESPACE

#endif // POPUP_H

