/****************************************************************************
** Meta object code from reading C++ file 'gamemanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../knights-26.07.80/src/gamemanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gamemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Knights7ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Knights::Manager::qt_create_metaobjectdata<qt_meta_tag_ZN7Knights7ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Knights::Manager",
        "timeChanged",
        "",
        "Color",
        "undoPossible",
        "redoPossible",
        "pieceMoved",
        "Move",
        "activePlayerChanged",
        "initComplete",
        "notification",
        "Offer",
        "winnerNotify",
        "historyChanged",
        "playerNameChanged",
        "levelChanged",
        "const KGameDifficultyLevel*",
        "moveByExternalControl",
        "moveByBoard",
        "sendOffer",
        "GameAction",
        "action",
        "player",
        "id",
        "setOfferResult",
        "OfferAction",
        "result",
        "initialize",
        "pause",
        "undo",
        "redo",
        "offerDraw",
        "adjourn",
        "abort",
        "loadGameHistoryFrom",
        "filename",
        "saveGameHistoryAs",
        "moveByProtocol",
        "protocolInitSuccesful",
        "gameOver",
        "setTimeRunning",
        "sendPendingMove"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timeChanged'
        QtMocHelpers::SignalData<void(Color, const QTime &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QTime, 2 },
        }}),
        // Signal 'undoPossible'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'redoPossible'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'pieceMoved'
        QtMocHelpers::SignalData<void(const Move &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'activePlayerChanged'
        QtMocHelpers::SignalData<void(Color)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'initComplete'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'notification'
        QtMocHelpers::SignalData<void(const Offer &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'winnerNotify'
        QtMocHelpers::SignalData<void(Color)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'historyChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerNameChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'levelChanged'
        QtMocHelpers::SlotData<void(const KGameDifficultyLevel *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'moveByExternalControl'
        QtMocHelpers::SlotData<void(const Move &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'moveByBoard'
        QtMocHelpers::SlotData<void(const Move &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'sendOffer'
        QtMocHelpers::SlotData<void(GameAction, Color, int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 3, 22 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'sendOffer'
        QtMocHelpers::SlotData<void(GameAction, Color)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 3, 22 },
        }}),
        // Slot 'sendOffer'
        QtMocHelpers::SlotData<void(GameAction)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'sendOffer'
        QtMocHelpers::SlotData<void(const Offer &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'setOfferResult'
        QtMocHelpers::SlotData<void(int, OfferAction)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'initialize'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'offerDraw'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'adjourn'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadGameHistoryFrom'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'saveGameHistoryAs'
        QtMocHelpers::SlotData<void(const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'moveByProtocol'
        QtMocHelpers::SlotData<void(const Move &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'protocolInitSuccesful'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gameOver'
        QtMocHelpers::SlotData<void(Color)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'setTimeRunning'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'sendPendingMove'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Manager, qt_meta_tag_ZN7Knights7ManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Knights::Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights7ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights7ManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Knights7ManagerE_t>.metaTypes,
    nullptr
} };

void Knights::Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timeChanged((*reinterpret_cast<std::add_pointer_t<Color>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTime>>(_a[2]))); break;
        case 1: _t->undoPossible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->redoPossible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->pieceMoved((*reinterpret_cast<std::add_pointer_t<Move>>(_a[1]))); break;
        case 4: _t->activePlayerChanged((*reinterpret_cast<std::add_pointer_t<Color>>(_a[1]))); break;
        case 5: _t->initComplete(); break;
        case 6: _t->notification((*reinterpret_cast<std::add_pointer_t<Offer>>(_a[1]))); break;
        case 7: _t->winnerNotify((*reinterpret_cast<std::add_pointer_t<Color>>(_a[1]))); break;
        case 8: _t->historyChanged(); break;
        case 9: _t->playerNameChanged(); break;
        case 10: _t->levelChanged((*reinterpret_cast<std::add_pointer_t<const KGameDifficultyLevel*>>(_a[1]))); break;
        case 11: _t->moveByExternalControl((*reinterpret_cast<std::add_pointer_t<Move>>(_a[1]))); break;
        case 12: _t->moveByBoard((*reinterpret_cast<std::add_pointer_t<Move>>(_a[1]))); break;
        case 13: _t->sendOffer((*reinterpret_cast<std::add_pointer_t<GameAction>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Color>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 14: _t->sendOffer((*reinterpret_cast<std::add_pointer_t<GameAction>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Color>>(_a[2]))); break;
        case 15: _t->sendOffer((*reinterpret_cast<std::add_pointer_t<GameAction>>(_a[1]))); break;
        case 16: _t->sendOffer((*reinterpret_cast<std::add_pointer_t<Offer>>(_a[1]))); break;
        case 17: _t->setOfferResult((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<OfferAction>>(_a[2]))); break;
        case 18: _t->initialize(); break;
        case 19: _t->pause((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->undo(); break;
        case 21: _t->redo(); break;
        case 22: _t->offerDraw(); break;
        case 23: _t->adjourn(); break;
        case 24: _t->abort(); break;
        case 25: _t->loadGameHistoryFrom((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->saveGameHistoryAs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->moveByProtocol((*reinterpret_cast<std::add_pointer_t<Move>>(_a[1]))); break;
        case 28: _t->protocolInitSuccesful(); break;
        case 29: _t->gameOver((*reinterpret_cast<std::add_pointer_t<Color>>(_a[1]))); break;
        case 30: _t->setTimeRunning((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->sendPendingMove(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(Color , const QTime & )>(_a, &Manager::timeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(bool )>(_a, &Manager::undoPossible, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(bool )>(_a, &Manager::redoPossible, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(const Move & )>(_a, &Manager::pieceMoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(Color )>(_a, &Manager::activePlayerChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::initComplete, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(const Offer & )>(_a, &Manager::notification, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(Color )>(_a, &Manager::winnerNotify, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::historyChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::playerNameChanged, 9))
            return;
    }
}

const QMetaObject *Knights::Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Knights::Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Knights7ManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Knights::Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void Knights::Manager::timeChanged(Color _t1, const QTime & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Knights::Manager::undoPossible(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Knights::Manager::redoPossible(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Knights::Manager::pieceMoved(const Move & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Knights::Manager::activePlayerChanged(Color _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Knights::Manager::initComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Knights::Manager::notification(const Offer & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Knights::Manager::winnerNotify(Color _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Knights::Manager::historyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Knights::Manager::playerNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
