/********************************************************************************
** Form generated from reading UI file 'promotiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROMOTIONDIALOG_H
#define UI_PROMOTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PromotionWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QRadioButton *radioButtonQueen;
    QRadioButton *radioButtonRook;
    QRadioButton *radioButtonBishop;
    QRadioButton *radioButtonKnight;

    void setupUi(QWidget *PromotionWidget)
    {
        if (PromotionWidget->objectName().isEmpty())
            PromotionWidget->setObjectName("PromotionWidget");
        PromotionWidget->resize(508, 146);
        verticalLayout = new QVBoxLayout(PromotionWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(PromotionWidget);
        groupBox->setObjectName("groupBox");
        QFont font;
        font.setBold(true);
        groupBox->setFont(font);
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        radioButtonQueen = new QRadioButton(groupBox);
        radioButtonQueen->setObjectName("radioButtonQueen");
        QFont font1;
        font1.setBold(false);
        radioButtonQueen->setFont(font1);
        radioButtonQueen->setChecked(true);

        horizontalLayout->addWidget(radioButtonQueen);

        radioButtonRook = new QRadioButton(groupBox);
        radioButtonRook->setObjectName("radioButtonRook");
        radioButtonRook->setFont(font1);

        horizontalLayout->addWidget(radioButtonRook);

        radioButtonBishop = new QRadioButton(groupBox);
        radioButtonBishop->setObjectName("radioButtonBishop");
        radioButtonBishop->setFont(font1);

        horizontalLayout->addWidget(radioButtonBishop);

        radioButtonKnight = new QRadioButton(groupBox);
        radioButtonKnight->setObjectName("radioButtonKnight");
        radioButtonKnight->setFont(font1);

        horizontalLayout->addWidget(radioButtonKnight);


        verticalLayout_2->addLayout(horizontalLayout);


        verticalLayout->addWidget(groupBox);


        retranslateUi(PromotionWidget);

        QMetaObject::connectSlotsByName(PromotionWidget);
    } // setupUi

    void retranslateUi(QWidget *PromotionWidget)
    {
        PromotionWidget->setWindowTitle(tr2i18n("Pawn Promotion", nullptr));
        groupBox->setTitle(tr2i18n("Promote pawn to:", nullptr));
        radioButtonQueen->setText(tr2i18n("&Queen", nullptr));
        radioButtonRook->setText(tr2i18n("Roo&k", nullptr));
        radioButtonBishop->setText(tr2i18n("B&ishop", nullptr));
        radioButtonKnight->setText(tr2i18n("&Knight", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PromotionWidget: public Ui_PromotionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROMOTIONDIALOG_H

