/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Knights.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KNIGHTSADAPTOR_H
#define KNIGHTSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "externalcontrol.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Knights
 */
class KnightsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Knights")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Knights\">\n"
"    <signal name=\"moveMade\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"move\"/>\n"
"    </signal>\n"
"    <method name=\"movePiece\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"move\"/>\n"
"    </method>\n"
"    <method name=\"pauseGame\"/>\n"
"    <method name=\"resumeGame\"/>\n"
"    <method name=\"undo\"/>\n"
"    <method name=\"offerDraw\"/>\n"
"    <method name=\"adjourn\"/>\n"
"    <method name=\"abort\"/>\n"
"  </interface>\n"
        "")
public:
    KnightsAdaptor(Knights::ExternalControl *parent);
    ~KnightsAdaptor() override;

    inline Knights::ExternalControl *parent() const
    { return static_cast<Knights::ExternalControl *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void abort();
    void adjourn();
    void movePiece(const QString &move);
    void offerDraw();
    void pauseGame();
    void resumeGame();
    void undo();
Q_SIGNALS: // SIGNALS
    void moveMade(const QString &move);
};

#endif
