/********************************************************************************
** Form generated from reading UI file 'customdifficultydialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMDIFFICULTYDIALOG_H
#define UI_CUSTOMDIFFICULTYDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_CustomDifficultyDialog
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *frame;
    QGridLayout *gridLayout;
    QLabel *searchDepthLabel;
    KPluralHandlingSpinBox *sbSearchDepth;
    QLabel *memorySizeLabel;
    QSpinBox *sbMemorySize;

    void setupUi(QWidget *CustomDifficultyDialog)
    {
        if (CustomDifficultyDialog->objectName().isEmpty())
            CustomDifficultyDialog->setObjectName("CustomDifficultyDialog");
        CustomDifficultyDialog->resize(631, 207);
        verticalLayout = new QVBoxLayout(CustomDifficultyDialog);
        verticalLayout->setObjectName("verticalLayout");
        frame = new QFrame(CustomDifficultyDialog);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout = new QGridLayout(frame);
        gridLayout->setObjectName("gridLayout");
        searchDepthLabel = new QLabel(frame);
        searchDepthLabel->setObjectName("searchDepthLabel");

        gridLayout->addWidget(searchDepthLabel, 0, 0, 1, 1);

        sbSearchDepth = new KPluralHandlingSpinBox(frame);
        sbSearchDepth->setObjectName("sbSearchDepth");

        gridLayout->addWidget(sbSearchDepth, 0, 1, 1, 1);

        memorySizeLabel = new QLabel(frame);
        memorySizeLabel->setObjectName("memorySizeLabel");

        gridLayout->addWidget(memorySizeLabel, 1, 0, 1, 1);

        sbMemorySize = new QSpinBox(frame);
        sbMemorySize->setObjectName("sbMemorySize");

        gridLayout->addWidget(sbMemorySize, 1, 1, 1, 1);


        verticalLayout->addWidget(frame);

#if QT_CONFIG(shortcut)
        searchDepthLabel->setBuddy(sbSearchDepth);
        memorySizeLabel->setBuddy(sbMemorySize);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CustomDifficultyDialog);

        QMetaObject::connectSlotsByName(CustomDifficultyDialog);
    } // setupUi

    void retranslateUi(QWidget *CustomDifficultyDialog)
    {
        searchDepthLabel->setText(tr2i18n("Search &depth:", nullptr));
        sbSearchDepth->setSpecialValueText(tr2i18n("Engine default", "Let the engine determine the search depth"));
        memorySizeLabel->setText(tr2i18n("Memory &size:", nullptr));
        sbMemorySize->setSuffix(tr2i18n(" MB", "Megabytes"));
        (void)CustomDifficultyDialog;
    } // retranslateUi

};

namespace Ui {
    class CustomDifficultyDialog: public Ui_CustomDifficultyDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMDIFFICULTYDIALOG_H

